==> haskell-mime-mail-0.5.1-239.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-JDvN07wevoJ9TDUYLzi5tu
key:                  mime-mail-0.5.1-JDvN07wevoJ9TDUYLzi5tu
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  dec347078197553eae9aeab6f0d3ca71
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-JDvN07wevoJ9TDUYLzi5tu
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    filepath-1.4.300.1 process-1.6.19.0
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.5.1-240-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-F7YYG5qrvPZ5VHhRCY08Yo
key:                  mime-mail-0.5.1-F7YYG5qrvPZ5VHhRCY08Yo
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  11c180f4d3f733c6652d226fb1ef7264
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-F7YYG5qrvPZ5VHhRCY08Yo
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    filepath-1.4.300.1 process-1.6.19.0
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
